@@ -1,8 +1,10 @@
 #' @title Visual check of model assumptions
 #' @name check_model
 #'
-#' @description Visual check of model various assumptions (normality of residuals,
-#' normality of random effects, linear relationship, homogeneity of variance,
+#' @description
+#'
+#' Visual check of model various assumptions (normality of residuals, normality
+#' of random effects, linear relationship, homogeneity of variance,
 #' multicollinearity).
 #'
 #' @param x A model object.
@@ -12,7 +14,8 @@
 #' @param check Character vector, indicating which checks for should be performed
 #'   and plotted. May be one or more of
 #'   \code{"all", "vif", "qq", "normality", "linearity", "ncv", "homogeneity", "outliers", "reqq"}.
-#'   \code{"reqq"} is a QQ-plot for random effects and only available for mixed models.
+#'   \code{"reqq"} is a QQ-plot for random effects and only available for mixed
+#'   models.
 #'   \code{"ncv"} is an alias for \code{"linearity"}, and checks for non-constant
 #'   variance, i.e. for heteroscedasticity, as well as the linear relationship.
 #'   By default, all possible checks are performed and plotted.
@@ -30,20 +33,21 @@
 #' @return The data frame that is used for plotting.
 #'
 #' @note This function just prepares the data for plotting. To create the plots,
-#' \CRANpkg{see} needs to be installed. Furthermore, this function suppresses
-#' all possible warnings. In case you observe suspicious plots, please refer to
-#' the dedicated functions (like \code{check_collinearity()}, \code{check_normality()}
-#' etc.) to get informative messages and warnings.
+#'   \CRANpkg{see} needs to be installed. Furthermore, this function suppresses
+#'   all possible warnings. In case you observe suspicious plots, please refer
+#'   to the dedicated functions (like \code{check_collinearity()},
+#'   \code{check_normality()} etc.) to get informative messages and warnings.
 #'
 #' @section Linearity Assumption:
-#' The plot \strong{Linearity} checks the assumption of linear
-#' relationship. However, the spread of dots also indicate possible
-#' heteroscedasticity (i.e. non-constant variance); hence, the alias \code{"ncv"}
-#' for this plot. \strong{Some caution is needed} when interpreting these plots.
-#' Although these plots are helpful to check model assumptions, they do not
-#' necessarily indicate so-called "lack of fit", e.g. missed non-linear
-#' relationships or interactions. Thus, it is always recommended to also look
-#' at \href{https://strengejacke.github.io/ggeffects/articles/introduction_partial_residuals.html}{effect plots, including partial residuals}.
+#' The plot \strong{Linearity} checks the assumption of linear relationship.
+#' However, the spread of dots also indicate possible heteroscedasticity (i.e.
+#' non-constant variance); hence, the alias \code{"ncv"} for this plot.
+#' \strong{Some caution is needed} when interpreting these plots. Although these
+#' plots are helpful to check model assumptions, they do not necessarily
+#' indicate so-called "lack of fit", e.g. missed non-linear relationships or
+#' interactions. Thus, it is always recommended to also look at
+#' \href{https://strengejacke.github.io/ggeffects/articles/introduction_partial_residuals.html}{effect
+#' plots, including partial residuals}.
 #'
 #' @section Residuals for (Generalized) Linear Models:
 #' Plots that check the normality of residuals (QQ-plot) or the homogeneity of
@@ -76,7 +80,19 @@ check_model <- function(x, ...) {
 
 #' @rdname check_model
 #' @export
-check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, check = "all", alpha = .2, dot_alpha = .8, colors = c("#3aaf85", "#1b6ca8", "#cd201f"), theme = "see::theme_lucid", detrend = FALSE, verbose = TRUE, ...) {
+check_model.default <- function(x,
+                                dot_size = 2,
+                                line_size = .8,
+                                panel = TRUE,
+                                check = "all",
+                                alpha = .2,
+                                dot_alpha = .8,
+                                colors = c("#3aaf85", "#1b6ca8", "#cd201f"),
+                                theme = "see::theme_lucid",
+                                detrend = FALSE,
+                                verbose = TRUE,
+                                ...) {
+
   # check model formula
   if (verbose) {
     insight::formula_ok(x)
@@ -109,8 +125,24 @@ check_model.default <- function(x, dot_size = 2, line_size = .8, panel = TRUE, c
 
 
 #' @export
-check_model.model_fit <- function(x, dot_size = 2, line_size = .8, panel = TRUE, check = "all", alpha = .2, detrend = FALSE, ...) {
-  check_model(x$fit, dot_size = dot_size, line_size = line_size, panel = panel, check = check, alpha = alpha, detrend = detrend, ...)
+check_model.model_fit <- function(x,
+                                  dot_size = 2,
+                                  line_size = .8,
+                                  panel = TRUE,
+                                  check = "all",
+                                  alpha = .2,
+                                  detrend = FALSE,
+                                  ...) {
+  check_model(
+    x$fit,
+    dot_size = dot_size,
+    line_size = line_size,
+    panel = panel,
+    check = check,
+    alpha = alpha,
+    detrend = detrend,
+    ...
+  )
 }
 
 
@@ -199,7 +231,13 @@ check_model.model_fit <- function(x, dot_size = 2, line_size = .8, panel = TRUE,
     # get samples from posterior and prior
 
     prior <- suppressWarnings(
-      stats::update(model, prior_PD = TRUE, refresh = -1, iter = 2000, chains = 2)
+      stats::update(
+        model,
+        prior_PD = TRUE,
+        refresh = -1,
+        iter = 2000,
+        chains = 2
+      )
     )
 
     d1 <- as.data.frame(model)
