@@ -36,7 +36,11 @@
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
 #' performance_accuracy(model)
 #' @export
-performance_accuracy <- function(model, method = c("cv", "boot"), k = 5, n = 1000, verbose = TRUE) {
+performance_accuracy <- function(model,
+                                 method = c("cv", "boot"),
+                                 k = 5,
+                                 n = 1000,
+                                 verbose = TRUE) {
   method <- match.arg(method)
 
   # get formula from model fit
@@ -194,3 +198,16 @@ performance_accuracy <- function(model, method = c("cv", "boot"), k = 5, n = 100
   }
   lapply(fold_idx, fold)
 }
+
+
+#' @export
+as.data.frame.performance_accuracy <- function(x, row.names = NULL, ...) {
+  data.frame(
+    Accuracy = x$Accuracy,
+    SE = x$SE,
+    Method = x$Method,
+    stringsAsFactors = FALSE,
+    row.names = row.names,
+    ...
+  )
+}
