@@ -32,11 +32,8 @@ performance_aic <- function(x, ...) {
 }
 
 
-
-
 # default -------------------------------------------------
 
-
 #' @export
 performance_aic.default <- function(x, ...) {
   info <- suppressWarnings(insight::model_info(x))
@@ -48,10 +45,7 @@ performance_aic.default <- function(x, ...) {
   }
 
   if (info$family == "Tweedie") {
-    if (!requireNamespace("tweedie", quietly = TRUE)) {
-      warning("Package 'tweedie' required for this function work. Please install it.", call. = FALSE)
-      return(NULL)
-    }
+    insight::check_if_installed("tweedie")
     aic <- suppressMessages(tweedie::AICtweedie(x))
   } else {
     aic <- tryCatch(
@@ -79,19 +73,12 @@ performance_aic.default <- function(x, ...) {
 }
 
 
-
-
-
-
 # VGAM models ------------------------------------
 
 
 #' @export
 performance_aic.vgam <- function(x, ...) {
-  if (!requireNamespace("VGAM", quietly = TRUE)) {
-    warning("Package 'VGAM' required for this function work. Please install it.", call. = FALSE)
-    return(NULL)
-  }
+  insight::check_if_installed("VGAM")
   VGAM::AIC(x)
 }
 
@@ -100,11 +87,6 @@ performance_aic.vglm <- performance_aic.vgam
 
 
 
-
-
-
-
-
 # Survey models --------------------------------------
 
 #' @export
@@ -156,9 +138,6 @@ performance_aic.betaor <- performance_aic.logitor
 performance_aic.betamfx <- performance_aic.logitor
 
 
-
-
-
 # Other models --------------------------------------
 
 #' @export
@@ -166,26 +145,14 @@ performance_aic.bayesx <- function(x, ...) {
   stats::AIC(x)[["AIC"]]
 }
 
-
-
-
-
-
 # methods ------------------------------------------
 
-
 #' @export
 AIC.bife <- function(object, ..., k = 2) {
   -2 * as.numeric(insight::get_loglikelihood(object)) + k * insight::get_df(object, type = "model")
 }
 
 
-
-
-
-
-
-
 # AICc ------------------------------------------
 
 
@@ -214,10 +181,7 @@ performance_aicc.Arima <- performance_aicc.bife
 
 #' @export
 performance_aicc.vglm <- function(x, ...) {
-  if (!requireNamespace("VGAM", quietly = TRUE)) {
-    warning("Package 'VGAM' required for this function work. Please install it.", call. = FALSE)
-    return(NULL)
-  }
+  insight::check_if_installed("VGAM")
   VGAM::AICc(x)
 }
 
