@@ -17,21 +17,34 @@
 #'
 #' @return A list with the conditional and marginal R2 values.
 #'
-#' @details Marginal and conditional r-squared values for mixed models are calculated
-#'  based on \cite{Nakagawa et al. 2017}. For more details on the computation
-#'  of the variances, see \code{?insight::get_variance}.
+#' @details
+#'
+#' Marginal and conditional r-squared values for mixed models are calculated
+#' based on \cite{Nakagawa et al. 2017}. For more details on the computation of
+#' the variances, see \code{?insight::get_variance}.
 #'  \cr \cr
-#'  The marginal r-squared considers only the variance of the fixed effects, while the
-#'  conditional r-squared takes both the fixed and random effects into account.
-#'  The random effect variances are actually the mean random effect variances,
-#'  thus the r-squared value is also appropriate for mixed models with random
-#'  slopes or nested random effects (see \cite{Johnson 2014}).
+#'  The marginal r-squared considers only the variance of the fixed effects,
+#'  while the conditional r-squared takes both the fixed and random effects into
+#'  account. The random effect variances are actually the mean random effect
+#'  variances, thus the r-squared value is also appropriate for mixed models
+#'  with random slopes or nested random effects (see \cite{Johnson 2014}).
 #'
 #' @references \itemize{
-#'  \item Hox, J. J. (2010). Multilevel analysis: techniques and applications (2nd ed). New York: Routledge.
-#'  \item Johnson, P. C. D. (2014). Extension of Nakagawa & Schielzeth’s R2 GLMM to random slopes models. Methods in Ecology and Evolution, 5(9), 944–946. \doi{10.1111/2041-210X.12225}
-#'  \item Nakagawa, S., & Schielzeth, H. (2013). A general and simple method for obtaining R2 from generalized linear mixed-effects models. Methods in Ecology and Evolution, 4(2), 133–142. \doi{10.1111/j.2041-210x.2012.00261.x}
-#'  \item Nakagawa, S., Johnson, P. C. D., & Schielzeth, H. (2017). The coefficient of determination R2 and intra-class correlation coefficient from generalized linear mixed-effects models revisited and expanded. Journal of The Royal Society Interface, 14(134), 20170213. \doi{10.1098/rsif.2017.0213}
+#'  \item Hox, J. J. (2010). Multilevel analysis: techniques and applications
+#'  (2nd ed). New York: Routledge.
+#'
+#'  \item Johnson, P. C. D. (2014). Extension of Nakagawa & Schielzeth’s R2 GLMM
+#'  to random slopes models. Methods in Ecology and Evolution, 5(9), 944–946.
+#'  \doi{10.1111/2041-210X.12225}
+#'
+#'  \item Nakagawa, S., & Schielzeth, H. (2013). A general and simple method for
+#'  obtaining R2 from generalized linear mixed-effects models. Methods in
+#'  Ecology and Evolution, 4(2), 133–142. \doi{10.1111/j.2041-210x.2012.00261.x}
+#'
+#'  \item Nakagawa, S., Johnson, P. C. D., & Schielzeth, H. (2017). The
+#'  coefficient of determination R2 and intra-class correlation coefficient from
+#'  generalized linear mixed-effects models revisited and expanded. Journal of
+#'  The Royal Society Interface, 14(134), 20170213. \doi{10.1098/rsif.2017.0213}
 #'  }
 #'
 #' @examples
@@ -44,7 +57,11 @@
 r2_nakagawa <- function(model, by_group = FALSE, tolerance = 1e-5) {
   vars <- tryCatch(
     {
-      insight::get_variance(model, tolerance = tolerance, name_fun = "r2()", name_full = "r-squared")
+      insight::get_variance(model,
+        tolerance = tolerance,
+        name_fun = "r2()",
+        name_full = "r-squared"
+      )
     },
     error = function(e) {
       if (inherits(e, c("simpleError", "error"))) {
@@ -121,3 +138,18 @@ r2_nakagawa <- function(model, by_group = FALSE, tolerance = 1e-5) {
     )
   }
 }
+
+
+
+
+#' @export
+as.data.frame.r2_nakagawa <- function(x, row.names = NULL, optional = FALSE, ...) {
+  data.frame(
+    R2_conditional = x$R2_conditional,
+    R2_marginal = x$R2_marginal,
+    stringsAsFactors = FALSE,
+    row.names = row.names,
+    optional = optional,
+    ...
+  )
+}
