@@ -14,19 +14,16 @@
 #' @examples
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
 #' r2_tjur(model)
-#'
 #' @references Tjur, T. (2009). Coefficients of determination in logistic regression models - A new proposal: The coefficient of discrimination. The American Statistician, 63(4), 366-372.
 #'
-#' @importFrom stats predict residuals
-#' @importFrom insight get_response model_info
 #' @export
 r2_tjur <- function(model) {
   # check for valid object class
-  if (!insight::model_info(model)$is_binomial) {
+  if (!insight::model_info(model, verbose = FALSE)$is_binomial) {
     stop("`model` must be binomial.")
   }
 
-  y <- .recode_to_zero(insight::get_response(model))
+  y <- .recode_to_zero(insight::get_response(model, verbose = FALSE))
   pred <- stats::predict(model, type = "response", re.form = NULL)
 
   # delete pred for cases with missing residuals
