@@ -13,8 +13,10 @@ if (require("testthat") && require("performance")) {
     expect_equal(model_performance(model)$R2_Tjur, 0.478, tolerance = 0.01)
     expect_equal(
       colnames(model_performance(model)),
-      c("AIC", "BIC", "R2_Tjur", "RMSE", "Sigma", "Log_loss", "Score_log",
-        "Score_spherical", "PCP")
+      c(
+        "AIC", "BIC", "R2_Tjur", "RMSE", "Sigma", "Log_loss", "Score_log",
+        "Score_spherical", "PCP"
+      )
     )
   })
 }
