@@ -1,6 +1,4 @@
 if (require("testthat") && require("performance") && require("MASS")) {
-  context("r2_mcfadden")
-
   options(contrasts = c("contr.treatment", "contr.poly"))
   data(housing, package = "MASS")
   model <- polr(Sat ~ Infl + Type + Cont, weights = Freq, data = housing)
@@ -15,12 +13,14 @@ if (require("testthat") && require("performance") && require("MASS")) {
         ),
         model_type = "Generalized Linear", class = "r2_generic"
       ),
-      tolerance = 1e-3)
+      tolerance = 1e-3
+    )
 
     expect_equal(
       r2(model),
       list(R2_Nagelkerke = c(`Nagelkerke's R2` = 0.108408289848161)),
-      tolerance = 1e-3
+      tolerance = 1e-3,
+      ignore_attr = TRUE
     )
   })
-}
\ No newline at end of file
+}
